from zarnitsa.DataAugmenter import AbstractDataAugmenter

from zarnitsa.nlp.DataAugmenterNLP import DataAugmenterNLP
from zarnitsa.stats.DataAugmenterInternally import DataAugmenterInternally
from zarnitsa.stats.DataAugmenterExternally import DataAugmenterExternally
from zarnitsa.series.DataAugmenterTimeSeries import DataAugmenterTimeSeries



import pandas as pd
from typing import Tuple
from abc import ABCMeta, abstractmethod



class AbstractDataAugmenter(metaclass=ABCMeta):
    @abstractmethod
    def augment_dataframe(self, df: pd.DataFrame) -> pd.DataFrame:
        """Augment dataframe data. Pandas dataframe"""

    @abstractmethod
    def augment_column(self, col: pd.Series,) -> pd.Series:
        """Augment column data. Pandas column"""

    @abstractmethod
    def _prepare_data_to_aug(
        self, col: pd.Series, freq=0.2
    ) -> Tuple[pd.Series, pd.Series]:
        """Get part of data. Not augment all of it except case freq=1.0"""



from setuptools import setup, find_packages

install_requires = [
    "numpy==1.18.5",
    "pandas==1.1.5",
    "scikit-learn==0.24.1",
    "nlpaug==1.1.3",
    "wget==3.2",
    "spacy==3.0.5",
]

setup(
    name="zarnitsa",
    packages=find_packages(),
    description="zarnitsa package for data augmentation",
    version="0.0.15",
    url="https://github.com/AlexKay28/zarnitsa",
    author="Kaigorodov Alexander",
    author_email="kaygorodo2305@gmail.com",
    download_url="https://pypi.org/project/zarnitsa/",
    install_requires=install_requires,
    keywords=["augmentation", "NLP", "distributions"],
    include_package_data=True,
)
